@@ -1,11 +1,11 @@
 #!/usr/local/bin/perl -w
 
-require 5.004; # or use CLex.pl
+require 5.004; 
 use strict;
 BEGIN {  unshift @INC, "../lib"; }
-package Parse::MyLex;
+package Parse::SExpressions;
 use Parse::Lex;
-@Parse::MyLex::ISA = qw(Parse::Lex);
+@Parse::SExpressions::ISA = qw(Parse::Lex);
 
 sub upto {
   my $self = shift;
@@ -52,7 +52,7 @@ my %apply = (
 Parse::Lex->exclusive('OPERATOR');
 my $lexer;
 Parse::Lex->trace;
-$lexer = Parse::MyLex->new(
+$lexer = Parse::SExpressions->new(
 			   'LEFTP' => '[\(]' => sub {
 			     $lexer->start('OPERATOR');
 			     my($operator, @operands) = $lexer->upto('RIGHTP');
